@@ -6,7 +6,6 @@
 #include <test/unit/math/ad_tolerances.hpp>
 #include <test/unit/math/is_finite.hpp>
 #include <test/unit/math/expect_near_rel.hpp>
-#include <test/unit/math/serializer.hpp>
 #include <test/unit/math/test_ad_matvar.hpp>
 #include <test/unit/util.hpp>
 #include <gtest/gtest.h>
@@ -129,14 +128,15 @@ void test_gradient(const ad_tolerances& tols, const F& f,
   Eigen::VectorXd grad_ad;
   double fx_ad = fx;
   stan::math::gradient<F>(f, x, fx_ad, grad_ad);
-  expect_near_rel("gradient() val", fx, fx_ad, tols.gradient_val_);
+  expect_near_rel("gradient() val", fx, fx_ad, tols.gradient_val_, "double",
+                  "var");
   if (!test_derivs || !is_finite(x) || !is_finite(fx))
     return;
   Eigen::VectorXd grad_fd;
   double fx_fd;
   stan::math::finite_diff_gradient_auto(f, x, fx_fd, grad_fd);
   expect_near_rel("gradient() grad for finite diff vs auto diff", grad_fd,
-                  grad_ad, tols.gradient_grad_);
+                  grad_ad, tols.gradient_grad_, "finite_diff", "var");
 }
 
 #ifndef STAN_MATH_TESTS_REV_ONLY
@@ -170,14 +170,15 @@ void test_gradient_fvar(const ad_tolerances& tols, const F& f,
   Eigen::VectorXd grad_ad;
   double fx_ad = fx;
   stan::math::gradient<double, F>(f, x, fx_ad, grad_ad);
-  expect_near_rel("gradient_fvar() val", fx, fx_ad, tols.gradient_fvar_val_);
+  expect_near_rel("gradient_fvar() val", fx, fx_ad, tols.gradient_fvar_val_,
+                  "double", "fvar<double>");
   if (!test_derivs || !is_finite(x) || !is_finite(fx))
     return;
   Eigen::VectorXd grad_fd;
   double fx_fd;
   stan::math::finite_diff_gradient_auto(f, x, fx_fd, grad_fd);
   expect_near_rel("gradient_fvar() grad", grad_fd, grad_ad,
-                  tols.gradient_fvar_grad_);
+                  tols.gradient_fvar_grad_, "finite_diff", "fvar<double>");
 }
 
 /**
@@ -211,7 +212,8 @@ void test_hessian_fvar(const ad_tolerances& tols, const F& f,
   Eigen::VectorXd grad_ad;
   Eigen::MatrixXd H_ad;
   stan::math::hessian<double, F>(f, x, fx_ad, grad_ad, H_ad);
-  expect_near_rel("hessian_fvar() val", fx, fx_ad, tols.hessian_fvar_val_);
+  expect_near_rel("hessian_fvar() val", fx, fx_ad, tols.hessian_fvar_val_,
+                  "double", "fvar<fvar<double>>");
   if (!test_derivs || !is_finite(x) || !is_finite(fx))
     return;
   double fx_fd;
@@ -219,9 +221,10 @@ void test_hessian_fvar(const ad_tolerances& tols, const F& f,
   Eigen::MatrixXd H_fd;
   stan::math::internal::finite_diff_hessian_auto(f, x, fx_fd, grad_fd, H_fd);
   expect_near_rel("hessian_fvar() grad", grad_fd, grad_ad,
-                  tols.hessian_fvar_grad_);
+                  tols.hessian_fvar_grad_, "finite_diff", "fvar<fvar<double>>");
   expect_near_rel("hessian_fvar() Hessian", H_fd, H_ad,
-                  tols.hessian_fvar_hessian_);
+                  tols.hessian_fvar_hessian_, "finite_diff",
+                  "fvar<fvar<double>>");
 }
 
 /**
@@ -255,15 +258,18 @@ void test_hessian(const ad_tolerances& tols, const F& f,
   Eigen::VectorXd grad_ad;
   Eigen::MatrixXd H_ad;
   stan::math::hessian<F>(f, x, fx_ad, grad_ad, H_ad);
-  expect_near_rel("hessian val", fx, fx_ad, tols.hessian_val_);
+  expect_near_rel("hessian val", fx, fx_ad, tols.hessian_val_, "double",
+                  "fvar<var>");
   if (!test_derivs || !is_finite(x) || !is_finite(fx))
     return;
   double fx_fd;
   Eigen::VectorXd grad_fd;
   Eigen::MatrixXd H_fd;
   stan::math::internal::finite_diff_hessian_auto(f, x, fx_fd, grad_fd, H_fd);
-  expect_near_rel("hessian() grad", grad_fd, grad_ad, tols.hessian_grad_);
-  expect_near_rel("hessian() Hessian", H_fd, H_ad, tols.hessian_hessian_);
+  expect_near_rel("hessian() grad", grad_fd, grad_ad, tols.hessian_grad_,
+                  "finite_diff", "fvar<var>");
+  expect_near_rel("hessian() Hessian", H_fd, H_ad, tols.hessian_hessian_,
+                  "finite_diff", "fvar<var>");
 }
 
 /**
@@ -297,7 +303,8 @@ void test_grad_hessian(const ad_tolerances& tols, const F& f,
   Eigen::MatrixXd H_ad;
   std::vector<Eigen::MatrixXd> grad_H_ad;
   stan::math::grad_hessian(f, x, fx_ad, H_ad, grad_H_ad);
-  expect_near_rel("grad_hessian() val", fx, fx_ad, tols.grad_hessian_val_);
+  expect_near_rel("grad_hessian() val", fx, fx_ad, tols.grad_hessian_val_,
+                  "double", "fvar<fvar<var>>");
   if (!test_derivs || !is_finite(x) || !is_finite(fx))
     return;
   double fx_fd;
@@ -305,11 +312,12 @@ void test_grad_hessian(const ad_tolerances& tols, const F& f,
   std::vector<Eigen::MatrixXd> grad_H_fd;
   stan::math::finite_diff_grad_hessian_auto(f, x, fx_fd, H_fd, grad_H_fd);
   expect_near_rel("grad_hessian() Hessian", H_fd, H_ad,
-                  tols.grad_hessian_hessian_);
+                  tols.grad_hessian_hessian_, "finite_diff", "fvar<fvar<var>>");
   EXPECT_EQ(x.size(), grad_H_fd.size());
   for (size_t i = 0; i < grad_H_fd.size(); ++i)
     expect_near_rel("grad_hessian() grad Hessian", grad_H_fd[i], grad_H_ad[i],
-                    tols.grad_hessian_grad_hessian_);
+                    tols.grad_hessian_grad_hessian_, "finite_diff",
+                    "fvar<fvar<var>>");
 }
 #endif
 
@@ -402,6 +410,7 @@ void expect_all_throw(const F& f, const Eigen::VectorXd& x) {
  */
 template <typename F>
 void expect_all_throw(const F& f, double x1) {
+  using stan::math::serialize_return;
   auto h = [&](auto v) { return serialize_return(eval(f(v(0)))); };
   Eigen::VectorXd x(1);
   x << x1;
@@ -419,6 +428,7 @@ void expect_all_throw(const F& f, double x1) {
  */
 template <typename F>
 void expect_all_throw(const F& f, double x1, double x2) {
+  using stan::math::serialize_return;
   auto h = [&](auto v) { return serialize_return(eval(f(v(0), v(1)))); };
   Eigen::VectorXd x(2);
   x << x1, x2;
@@ -437,6 +447,7 @@ void expect_all_throw(const F& f, double x1, double x2) {
  */
 template <typename F>
 void expect_all_throw(const F& f, double x1, double x2, double x3) {
+  using stan::math::serialize_return;
   auto h = [&](auto v) { return serialize_return(eval(f(v(0), v(1), v(2)))); };
   Eigen::VectorXd x(3);
   x << x1, x2, x3;
@@ -467,6 +478,7 @@ void expect_all_throw(const F& f, double x1, double x2, double x3) {
 template <typename F, typename G, typename... Ts>
 void expect_ad_helper(const ad_tolerances& tols, const F& f, const G& g,
                       const Eigen::VectorXd& x, Ts... xs) {
+  using stan::math::serialize;
   auto h
       = [&](const int i) { return [&g, i](const auto& v) { return g(v)[i]; }; };
   size_t result_size = 0;
@@ -498,6 +510,9 @@ void expect_ad_helper(const ad_tolerances& tols, const F& f, const G& g,
  */
 template <typename F, typename T>
 void expect_ad_v(const ad_tolerances& tols, const F& f, const T& x) {
+  using stan::math::serialize_args;
+  using stan::math::serialize_return;
+  using stan::math::to_deserializer;
   auto g = [&](const auto& v) {
     auto ds = to_deserializer(v);
     auto xds = ds.read(x);
@@ -559,6 +574,9 @@ void expect_ad_v(const ad_tolerances& tols, const F& f, int x) {
 template <typename F, typename T1, typename T2>
 void expect_ad_vv(const ad_tolerances& tols, const F& f, const T1& x1,
                   const T2& x2) {
+  using stan::math::serialize_args;
+  using stan::math::serialize_return;
+  using stan::math::to_deserializer;
   // d.x1
   auto g1 = [&](const auto& v) {
     auto ds = to_deserializer(v);
@@ -671,6 +689,9 @@ void expect_ad_vv(const ad_tolerances& tols, const F& f, int x1, int x2) {
 template <typename F, typename T1, typename T2, typename T3>
 void expect_ad_vvv(const ad_tolerances& tols, const F& f, const T1& x1,
                    const T2& x2, const T3& x3) {
+  using stan::math::serialize_args;
+  using stan::math::serialize_return;
+  using stan::math::to_deserializer;
   // d.x1
   auto g1 = [&](const auto& v) {
     auto ds = to_deserializer(v);
